﻿// Copyright (C) Microsoft Corporation. All Rights Reserved.
// This code released under the terms of the Microsoft Public License
// (Ms-PL, http://opensource.org/licenses/ms-pl.html).

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Phone.Controls;

namespace ListPickerSamples
{
    public partial class MainPage : PhoneApplicationPage
    {
        private readonly Random _rand = new Random();

        public MainPage()
        {
            InitializeComponent();
        }

        private void RatingSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            RatingSelection.Text = "Current selection: " + ((0 < e.AddedItems.Count) ? e.AddedItems[0] : "[nothing]");
        }

        private void RandomSelectionClick(object sender, RoutedEventArgs e)
        {
            RatingSelector.SelectedIndex = _rand.Next(RatingSelector.Items.Count);
        }
    }

    public class Model : INotifyPropertyChanged
    {
        public IEnumerable<string> Ratings { get; private set; }
        public IEnumerable<string> Rainbow { get; private set; }
        public Network[] Networks { get; private set; }

        public Network CurrentNetwork
        {
            get { return _currentNetwork; }
            set
            {
                _currentNetwork = value;
                InvokePropertyChanged("CurrentNetwork");
            }
        }
        private Network _currentNetwork;

        public Model()
        {
            Ratings = "Excellent Good Fair Poor".Split();
            Rainbow = "Red Orange Yellow Green Blue Purple".Split();
            Networks = new Network[] { new Network { Name = "Work" }, new Network { Name = "Home" }, new Network { Name = "Roaming" } };
            CurrentNetwork = Networks[1];
        }

        private void InvokePropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (null != handler)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }

    public class Network
    {
        public string Name { get; set; }

        public override string ToString()
        {
            return Name;
        }
    }
}
